@@ -1,21 +1,15 @@
 context("txtq")
 
-test_that("core txtq utilities work", {
+test_that("core txtq API works", {
   q <- txtq(tempfile())
   expect_true(file.exists(q$path()))
   expect_true(q$empty())
   expect_equal(q$count(), 0)
   expect_equal(q$total(), 0)
-  null_df <- data.frame(
-    title = character(0),
-    message = character(0),
-    time = as.POSIXct(character(0)),
-    stringsAsFactors = FALSE
-  )
-  expect_equal(q$pop(), null_df)
-  expect_equal(q$pop(), null_df)
-  expect_equal(q$list(), null_df)
-  expect_equal(q$log(), null_df)
+  expect_equal(q$pop(), null_log)
+  expect_equal(q$pop(), null_log)
+  expect_equal(q$list(), null_log)
+  expect_equal(q$log(), null_log)
   expect_equal(q$count(), 0)
   expect_equal(q$total(), 0)
   q$push(title = 1:2, message = 2:3)
@@ -45,7 +39,7 @@ test_that("core txtq utilities work", {
   expect_equal(out$message, full_df[-1, "message"])
   expect_true(q$empty())
   expect_equal(q$count(), 0)
-  expect_equal(q$list(), null_df)
+  expect_equal(q$list(), null_log)
   expect_equal(q$log()[, cols], full_df)
   q$push(title = "new", message = "message")
   expect_false(q$empty())
@@ -62,7 +56,7 @@ test_that("core txtq utilities work", {
   expect_false(file.exists(q$path()))
 })
 
-test_that("$reset()", {
+test_that("reset()", {
   q <- txtq(tempfile())
   expect_equal(q$count(), 0)
   expect_equal(q$total(), 0)
@@ -86,7 +80,7 @@ test_that("$reset()", {
   expect_equal(nrow(q$log()), 0)
 })
 
-test_that("$clean()", {
+test_that("clean()", {
   df <- function(index){
     data.frame(
       title = as.character(index),
@@ -111,46 +105,9 @@ test_that("$clean()", {
   }
 })
 
-test_that("txtq is thread safe", {
-  f <- function(process, in_, out_){
-    q <- txtq::txtq(in_)
-    if (identical(process, "A")){
-      while (nrow(q$log()) < 1000 || !q$empty()){
-        i <- 1
-        p <- txtq::txtq(out_)
-        msg <- q$pop()
-        if (nrow(msg) > 0){
-          p$push(msg$title, msg$message)
-        }
-      }
-    } else {
-      for (i in seq_len(1000)){
-        q$push(title = as.character(i), message = as.character(i + 1))
-      }
-    }
-  }
-  cl <- parallel::makePSOCKcluster(2)
-  in_ <- tempfile()
-  out_ <- tempfile()
-  parallel::parLapply(
-    cl = cl, X = c("A", "B"), fun = f, in_ = in_, out_ = out_)
-  parallel::stopCluster(cl)
-  q <- txtq(in_)
-  p <- txtq(out_)
-  cols <- c("title", "message")
-  expect_equal(nrow(q$list()), 0)
-  expect_equal(nrow(q$log()), 1000)
-  expect_equal(nrow(p$log()), 1000)
-  expect_equal(p$list()[, cols], q$log()[, cols])
-  expect_equal(p$list()[, cols], p$log()[, cols])
-})
-
-
-test_that("long message", {
-  q <- txtq(tempfile())
-  s <- paste(sample(LETTERS, 3000000, TRUE), collapse = "")
-  q$push(title = "long", message = s)
-  out <- q$pop(-1)
-  expect_equal(s, out$message)
-  q$destroy()
+test_that("subdirectories (#13)", {
+  f <- file.path(tempfile(), "x", "y", "z")
+  q <- txtq(f)
+  q$push("x", "y")
+  expect_equal(q$pop()$title, "x")
 })
